Index: wp-admin/custom-header.php
===================================================================
--- wp-admin/custom-header.php	(revision 6534)
+++ wp-admin/custom-header.php	(working copy)
@@ -228,7 +228,7 @@
 
 		if ( $width == HEADER_IMAGE_WIDTH && $height == HEADER_IMAGE_HEIGHT ) {
 			set_theme_mod('header_image', clean_url($url));
-			apply_filters('wp_create_file_in_uploads', $file, $id); // For replication
+			do_action('wp_create_file_in_uploads', $file, $id); // For replication
 			return $this->finished();
 		} elseif ( $width > HEADER_IMAGE_WIDTH ) {
 			$oitar = $width / HEADER_IMAGE_WIDTH;
Index: wp-admin/import/wordpress.php
===================================================================
--- wp-admin/import/wordpress.php	(revision 6534)
+++ wp-admin/import/wordpress.php	(working copy)
@@ -106,7 +106,6 @@
 					continue;
 				}
 				if ( false !== strpos($importline, '</item>') ) {
-					$num++;
 					$doing_entry = false;
 					if ($process_post_func)
 						call_user_func($process_post_func, $this->post);
@@ -400,7 +399,7 @@
 
 			$post_author = $this->checkauthor($post_author); //just so that if a post already exists, new users are not created by checkauthor
 
-			$postdata = compact('post_author', 'post_date', 'post_date_gmt', 'post_content', 'post_title', 'post_excerpt', 'post_status', 'post_name', 'comment_status', 'ping_status', 'post_modified', 'post_modified_gmt', 'guid', 'post_parent', 'menu_order', 'post_type');
+			$postdata = compact('post_author', 'post_date', 'post_date_gmt', 'post_content', 'post_title', 'post_status', 'post_name', 'comment_status', 'ping_status', 'guid', 'post_parent', 'menu_order', 'post_type');
 			if ($post_type == 'attachment') {
 				$remote_url = $this->get_tag( $post, 'wp:attachment_url' );
 				if ( !$remote_url )
Index: wp-admin/import/wp-cat2tag.php
===================================================================
--- wp-admin/import/wp-cat2tag.php	(revision 6534)
+++ wp-admin/import/wp-cat2tag.php	(working copy)
@@ -114,8 +114,6 @@
 	}
 
 	function _category_exists($cat_id) {
-		global $wpdb;
-
 		$cat_id = (int) $cat_id;
 
 		$maybe_exists = category_exists($cat_id);
Index: wp-admin/includes/file.php
===================================================================
--- wp-admin/includes/file.php	(revision 6534)
+++ wp-admin/includes/file.php	(working copy)
@@ -112,6 +112,7 @@
 
 	// If you override this, you must provide $ext and $type!!!!
 	$test_type = true;
+	$mimes = false;
 
 	// Install user overrides. Did we mention that this voids your warranty?
 	if ( is_array( $overrides ) )
Index: wp-admin/includes/misc.php
===================================================================
--- wp-admin/includes/misc.php	(revision 6534)
+++ wp-admin/includes/misc.php	(working copy)
@@ -129,8 +129,8 @@
 }
 
 // If siteurl or home changed, flush rewrite rules.
-function update_home_siteurl( $old_value, $value ) {
-	global $wp_rewrite, $user_login, $user_pass_md5;
+function update_home_siteurl( $deprecated = '', $deprecated = '' ) {
+	global $wp_rewrite;
 
 	if ( defined( "WP_INSTALLING" ) )
 		return;
@@ -139,8 +139,8 @@
 	$wp_rewrite->flush_rules();
 }
 
-add_action( 'update_option_home', 'update_home_siteurl', 10, 2 );
-add_action( 'update_option_siteurl', 'update_home_siteurl', 10, 2 );
+add_action( 'update_option_home', 'update_home_siteurl');
+add_action( 'update_option_siteurl', 'update_home_siteurl');
 
 function url_shorten( $url ) {
 	$short_url = str_replace( 'http://', '', stripslashes( $url ));
Index: wp-admin/includes/template.php
===================================================================
--- wp-admin/includes/template.php	(revision 6534)
+++ wp-admin/includes/template.php	(working copy)
@@ -102,11 +102,6 @@
 		echo ' checked="checked"';
 }
 
-// TODO: Remove?
-function documentation_link( $for ) {
-	return;
-}
-
 function selected( $selected, $current) {
 	if ( $selected == $current)
 		echo ' selected="selected"';
Index: wp-admin/includes/update.php
===================================================================
--- wp-admin/includes/update.php	(revision 6534)
+++ wp-admin/includes/update.php	(working copy)
@@ -2,7 +2,7 @@
 
 // The admin side of our 1.0 update system
 
-function core_update_footer( $msg ) {
+function core_update_footer( $deprecated = '' ) {
 	if ( !current_user_can('manage_options') )
 		return sprintf( '| '.__( 'Version %s' ), $GLOBALS['wp_version'] );
 
Index: wp-admin/link-import.php
===================================================================
--- wp-admin/link-import.php	(revision 6534)
+++ wp-admin/link-import.php	(working copy)
@@ -123,7 +123,7 @@
 } // end else
 
 if ( ! $blogrolling )
-	apply_filters( 'wp_delete_file', $opml_url);
+	do_action( 'wp_delete_file', $opml_url);
 	@unlink($opml_url);
 ?>
 </div>
Index: wp-app.php
===================================================================
--- wp-app.php	(revision 6534)
+++ wp-app.php	(working copy)
@@ -425,7 +425,7 @@
 		$url = $file['url'];
 		$file = $file['file'];
 
-		apply_filters('wp_create_file_in_uploads', $file); // replicate
+		do_action('wp_create_file_in_uploads', $file); // replicate
 
 		// Construct the attachment array
 		$attachment = array(
Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 6534)
+++ wp-includes/category-template.php	(working copy)
@@ -66,7 +66,7 @@
 }
 
 function get_the_category($id = false) {
-	global $post, $term_cache;
+	global $post;
 
 	$id = (int) $id;
 	if ( !$id )
Index: wp-includes/classes.php
===================================================================
--- wp-includes/classes.php	(revision 6534)
+++ wp-includes/classes.php	(working copy)
@@ -740,7 +740,7 @@
 
 		$r = wp_parse_args( $args, $defaults );
 		extract( $r, EXTR_SKIP );
-		$postition = preg_replace( '/[^a-z0-9:_-]/i', '', $position );
+		$position = preg_replace( '/[^a-z0-9:_-]/i', '', $position );
 
 		if ( is_wp_error($id) ) {
 			$data = $id;
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 6534)
+++ wp-includes/comment.php	(working copy)
@@ -105,7 +105,7 @@
 
 // Deprecate in favor of get_comment()?
 function get_commentdata( $comment_ID, $no_cache = 0, $include_unapproved = false ) { // less flexible, but saves DB queries
-	global $postc, $id, $wpdb;
+	global $postc, $wpdb;
 	if ( $no_cache ) {
 		$query = $wpdb->prepare("SELECT * FROM $wpdb->comments WHERE comment_ID = %d", $comment_ID);
 		if ( false == $include_unapproved )
@@ -130,7 +130,6 @@
 
 function get_lastcommentmodified($timezone = 'server') {
 	global $cache_lastcommentmodified, $wpdb;
-	$add_seconds_blog = get_option('gmt_offset') * 3600;
 	$add_seconds_server = date('Z');
 	$now = current_time('mysql', 1);
 	if ( !isset($cache_lastcommentmodified[$timezone]) ) {
@@ -177,7 +176,7 @@
         "total_comments"        => 0
     ); 
 
-    foreach ( $totals as $i => $row ) { 
+    foreach ( $totals as $row ) { 
         switch ( $row['comment_approved'] ) { 
             case 'spam': 
                 $comment_count['spam'] = $row['total']; 
@@ -519,7 +518,7 @@
 
 	$comment_date_gmt = get_gmt_from_date($comment_date);
 
-	$result = $wpdb->query(
+	$wpdb->query(
 		"UPDATE $wpdb->comments SET
 			comment_content      = '$comment_content',
 			comment_author       = '$comment_author',
@@ -609,7 +608,6 @@
 	$pingback_str_dquote = 'rel="pingback"';
 	$pingback_str_squote = 'rel=\'pingback\'';
 	$x_pingback_str = 'x-pingback: ';
-	$pingback_href_original_pos = 27;
 
 	extract(parse_url($url), EXTR_SKIP);
 
Index: wp-includes/cron.php
===================================================================
--- wp-includes/cron.php	(revision 6534)
+++ wp-includes/cron.php	(working copy)
@@ -143,7 +143,7 @@
 	$key = md5(serialize($args));
 	if ( empty($crons) )
 		return false;
-	foreach ( $crons as $timestamp => $cron ) {
+	foreach ( $crons as $cron ) {
 		if ( isset( $cron[$hook][$key] ) )
 			return $cron[$hook][$key]['schedule'];
 	}
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 6534)
+++ wp-includes/deprecated.php	(working copy)
@@ -911,7 +911,7 @@
  *
  * @param string $file
  */
-function permalink_single_rss($file = '') {
+function permalink_single_rss($deprecated = '') {
 	_deprecated_function(__FUNCTION__, '0.0', 'the_permalink_rss()');
 	the_permalink_rss();
 }
@@ -1206,7 +1206,7 @@
 function get_category_rss_link($echo = false, $cat_ID = 1, $deprecated = '') {
 	_deprecated_function(__FUNCTION__, '0.0', 'get_category_feed_link()');
 
-	$link = get_category_feed_link($cat_ID, $feed = 'rss2');
+	$link = get_category_feed_link($cat_ID, 'rss2');
 
 	if ( $echo )
 		echo $link;
@@ -1263,4 +1263,15 @@
 	return wp_create_user($username, $password, $email);
 }
 
+/**
+ * documentation_link() - Unused Admin function
+ * @since 2.0
+ * @param string $deprecated Unknown
+ * @deprecated 2.4
+ */
+function documentation_link( $deprecated = '' ) {
+	_deprecated_function( __FUNCTION__, '2.4', '' );
+	return;
+}
+
 ?>
\ No newline at end of file
Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 6534)
+++ wp-includes/functions.php	(working copy)
@@ -115,7 +115,7 @@
 	$day = mktime( 0, 0, 0, $md, $mm, $my );
 	$weekday = date( 'w', $day );
 	$i = 86400;
-	if( !is_numeric($a) )
+	if( !is_numeric($start_of_week) )
 		$start_of_week = get_option( 'start_of_week' );
 
 	if ( $weekday < $start_of_week )
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 6534)
+++ wp-includes/link-template.php	(working copy)
@@ -32,7 +32,7 @@
 	global $post;
 	switch ( strtolower($mode) ) {
 		case 'title':
-			$title = sanitize_title($post->post_title) . '-' . $id;
+			$title = sanitize_title($post->post_title) . '-' . $post->ID;
 			echo '<a id="'.$title.'"></a>';
 			break;
 		case 'id':
@@ -316,7 +316,7 @@
 	if ( '' == $permalink_structure ) {
 		$link = get_option('home') . '?feed=rss2&amp;author=' . $author_id;
 	} else {
-		$link = get_author_posts_url($author_id, $author_nicename);
+		$link = get_author_posts_url($author_id);
 		$link = trailingslashit($link) . user_trailingslashit('feed', 'feed');
 	}
 
Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 6534)
+++ wp-includes/pluggable.php	(working copy)
@@ -291,8 +291,8 @@
 endif;
 
 if ( !function_exists('wp_login') ) :
-function wp_login($username, $password, $deprecated = false) {
-	global $wpdb, $error;
+function wp_login($username, $password, $deprecated = '') {
+	global $error;
 
 	$username = sanitize_user($username);
 
@@ -802,6 +802,7 @@
 // Deprecated. Use wp_set_auth_cookie()
 if ( !function_exists('wp_setcookie') ) :
 function wp_setcookie($username, $password = '', $already_md5 = false, $home = '', $siteurl = '', $remember = false) {
+	_deprecated_function( __FUNCTION__, '2.4', 'wp_set_auth_cookie()' );
 	$user = get_userdatabylogin($username);
 	wp_set_auth_cookie($user->ID, $remember);
 }
@@ -810,6 +811,7 @@
 // Deprecated. Use wp_clear_auth_cookie()
 if ( !function_exists('wp_clearcookie') ) :
 function wp_clearcookie() {
+	_deprecated_function( __FUNCTION__, '2.4', 'wp_clear_auth_cookie()' );
 	wp_clear_auth_cookie();
 }
 endif;
@@ -817,6 +819,7 @@
 // Deprecated.  No alternative.
 if ( !function_exists('wp_get_cookie_login') ):
 function wp_get_cookie_login() {
+	_deprecated_function( __FUNCTION__, '2.4', '' );
 	return false;
 }
 endif;
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 6534)
+++ wp-includes/post.php	(working copy)
@@ -2529,7 +2529,7 @@
  * @param int $post_id Not Used. Can be set to null.
  * @param object $post Object type containing the post information
  */
-function _future_post_hook($post_id, $post) {
+function _future_post_hook($deprecated = '', $post) {
 	wp_clear_scheduled_hook( 'publish_future_post', $post->ID );
 	wp_schedule_single_event(strtotime($post->post_date_gmt. ' GMT'), 'publish_future_post', array($post->ID));
 }
Index: wp-includes/rss.php
===================================================================
--- wp-includes/rss.php	(revision 6534)
+++ wp-includes/rss.php	(working copy)
@@ -710,7 +710,6 @@
 \*=======================================================================*/
 	function check_cache ( $url ) {
 		$this->ERROR = "";
-		$cache_option = $this->file_name( $url );
 		$cache_timestamp = 'rss_' . $this->file_name( $url ) . '_ts';
 
 		if ( $mtime = get_option($cache_timestamp) ) {
Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 6534)
+++ wp-includes/taxonomy.php	(working copy)
@@ -806,7 +806,7 @@
 			
 	} else if ( 'rss' == $context ) {
 		$value = apply_filters("term_${field}_rss", $value, $taxonomy);
-		$value = apply_filters("${taxonomy}_$field_rss", $value);
+		$value = apply_filters("${taxonomy}_${field}_rss", $value);
 	} else {
 		// Use display filters by default.
 		$value = apply_filters("term_$field", $value, $term_id, $taxonomy, $context);


Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 6534)
+++ wp-includes/comment-template.php	(working copy)
@@ -340,10 +340,10 @@
  *
  * @since 0.71
  *
  * @param string $file Not Used
  * @param bool $echo Not Used
  */
-function comments_link( $file = '', $echo = true ) {
+function comments_link( $deprecated = '', $deprecated = '' ) {
 	echo get_comments_link();
 }
 
@@ -357,6 +357,7 @@
  * @return int The number of comments a post has
  */
 function get_comments_number( $post_id = 0 ) {
+	global $id;
 	$post_id = (int) $post_id;
 
 	if ( !$post_id )
@@ -536,9 +537,9 @@
  *
  * @since 0.71
  *
  * @param int $timezone Not used
  */
-function trackback_rdf($timezone = 0) {
+function trackback_rdf($deprecated = '') {
 	if (stripos($_SERVER['HTTP_USER_AGENT'], 'W3C_Validator') === false) {
 		echo '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
 				xmlns:dc="http://purl.org/dc/elements/1.1/"
@@ -340,10 +340,10 @@
  * @since 0.71
  *
- * @param string $file Not Used
- * @param bool $echo Not Used
+ * @param string $deprecated Not Used
+ * @param bool $deprecated Not Used
  */
@@ -536,9 +537,9 @@
  * @since 0.71
  *
- * @param int $timezone Not used
+ * @param int $deprecated Not used (Was $timezone = 0)
  */